@@ -27,6 +27,8 @@
 #include "kdocumentviewer.h"
 #include "interfaces/viewerinterface.h"
 
+#include "okular_part_export.h"
+
 #include <QtDBus/QtDBus>
 
 class QAction;
@@ -35,6 +37,7 @@ class QPrinter;
 class QMenu;
 
 class KUrl;
+class KConfigDialog;
 class KConfigGroup;
 class KDirWatch;
 class KToggleAction;
@@ -90,12 +93,14 @@ enum EmbedMode
  * @author Wilco Greven <greven@kde.org>
  * @version 0.2
  */
-class Part : public KParts::ReadWritePart, public Okular::DocumentObserver, public KDocumentViewer, public Okular::ViewerInterface
+class OKULAR_PART_EXPORT Part : public KParts::ReadWritePart, public Okular::DocumentObserver, public KDocumentViewer, public Okular::ViewerInterface
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.okular")
     Q_INTERFACES(KDocumentViewer)
     Q_INTERFACES(Okular::ViewerInterface)
+    
+    friend class PartTest;
 
     public:
         // Default constructor
@@ -111,7 +116,6 @@ class Part : public KParts::ReadWritePart, public Okular::DocumentObserver, publ
         ~Part();
 
         // inherited from DocumentObserver
-        uint observerId() const { return PART_ID; }
         void notifySetup( const QVector< Okular::Page * > &pages, int setupFlags );
         void notifyViewportChanged( bool smoothMove );
         void notifyPageChanged( int page, int flags );
@@ -145,6 +149,7 @@ class Part : public KParts::ReadWritePart, public Okular::DocumentObserver, publ
         Q_SCRIPTABLE void slotGotoLast();
         Q_SCRIPTABLE void slotTogglePresentation();
         Q_SCRIPTABLE Q_NOREPLY void reload();
+        Q_SCRIPTABLE Q_NOREPLY void enableStartWithPrint();
 
     signals:
         void enablePrintAction(bool enable);
@@ -184,7 +189,6 @@ class Part : public KParts::ReadWritePart, public Okular::DocumentObserver, publ
         void slotSaveCopyAs();
         void slotGetNewStuff();
         void slotNewConfig();
-        void slotNewGeneratorConfig();
         void slotShowMenu(const Okular::Page *page, const QPoint &point);
         void slotShowProperties();
         void slotShowEmbeddedFiles();
@@ -218,6 +222,7 @@ class Part : public KParts::ReadWritePart, public Okular::DocumentObserver, publ
         void slotFileDirty( const QString& );
         void slotDoFileDirty();
         void psTransformEnded(int, QProcess::ExitStatus);
+        KConfigDialog * slotGeneratorPreferences();
 
     private:
         void setupViewerActions();
@@ -231,6 +236,7 @@ class Part : public KParts::ReadWritePart, public Okular::DocumentObserver, publ
         void updateAboutBackendAction();
         void unsetDummyMode();
         void slotRenameBookmark( const DocumentViewport &viewport );
+        void resetStartArguments();
         
         static int numberOfParts;
 
@@ -316,6 +322,7 @@ class Part : public KParts::ReadWritePart, public Okular::DocumentObserver, publ
         QList<Okular::ExportFormat> m_exportFormats;
         QList<QAction*> m_bookmarkActions;
         bool m_cliPresentation;
+        bool m_cliPrint;
         QString m_addBookmarkText;
         QIcon m_addBookmarkIcon;
 
@@ -327,7 +334,7 @@ class Part : public KParts::ReadWritePart, public Okular::DocumentObserver, publ
         FileKeeper *m_keeper;
 
     private slots:
-        void slotGeneratorPreferences();
+        void slotAnnotationPreferences();
         void slotHandleActivatedSourceReference(const QString& absFileName, int line, int col, bool *handled);
 };
 
